@@ -122,10 +122,10 @@ def exception_handler(exc, context):
         set_rollback()
         return done(
             code=code,
-            describe=ComCodeChoice.choices_map[code],
+            message=ComCodeChoice.choices_map[code],
             errors=data,
         )
-    return done(code=code, describe=msg)
+    return done(code=code, message=msg)
 
 
 def com_exception_handler(exc, context):
