@@ -20,7 +20,8 @@ def make_data(code=200, message='', **kwargs):
 
     resp = dict(
         code=code,
-        describe=message, **kwargs
+        message=message,
+        **kwargs
     )
     return resp
 
@@ -45,7 +46,8 @@ def done(code=200, message='成功', **kwargs):
     :return:
     """
     data = make_response(
-        code=code, message=message,
+        code=code,
+        message=message,
         **kwargs
     )
     return data
